Module config

Module config 

Open and recovery options for crate::db::Database.

Structs

OpenOptions
Options for crate::db::Database::open_with_options and in-memory open helpers.
OpenOptionsBuilder
Builder for OpenOptions.
OpenRecoveryInfo
Metadata about recovery actions applied during open.

Enums

OpenMode
Open mode for on-disk databases.
RecoveryMode
How to open a database when the append log tail may be torn or hold an uncommitted transaction.