pub enum RecoveryMode {
AutoTruncate,
Strict,
}Expand description
How to open a database when the append log tail may be torn or hold an uncommitted transaction.
Variants
AutoTruncate
Truncate the store to the last committed prefix (see docs/migration_0.7_to_0.8.md).
Strict
Return crate::error::FormatError::UncleanLogTail if the tail is not fully committed.