SchemaChange

Enum SchemaChange 

pub enum SchemaChange {
    Safe,
    NeedsMigration {
        reason: String,
        backfill_top_level_field: Option<String>,
        backfill_field_path: Option<FieldPath>,
    },
    Breaking {
        reason: String,
    },
}
Compatibility classification for a proposed schema update.

Variants



Safe

Update is safe to apply without rewriting existing data.



NeedsMigration

Update is supported, but existing data must be rewritten/backfilled first.

Fields

reason: String
backfill_top_level_field: Option<String>

Top-level field name to backfill when adding a new required single-segment field.

backfill_field_path: Option<FieldPath>

Full path to backfill when adding a new required field (any segment count).



Breaking

Update is not supported/safe and should be rejected by default.

Fields

reason: String