pub enum SchemaChange {
Safe,
NeedsMigration {
reason: String,
backfill_top_level_field: Option<String>,
backfill_field_path: Option<FieldPath>,
},
Breaking {
reason: String,
},
}Expand description
Compatibility classification for a proposed schema update.
Variants
Safe
Update is safe to apply without rewriting existing data.
NeedsMigration
Update is supported, but existing data must be rewritten/backfilled first.
Fields
Breaking
Update is not supported/safe and should be rejected by default.